# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "0.3.1"
FULL_VERSION = "0.3.1.1.0"

ARCHIVES_BASE_NAME = "YAHA"
CARDINAL_COMPONENTS_VERSION = "5.2.1"
CLOTH_CONFIG_VERSION = "11.1.118"
FABRIC_VERSION = "0.92.6+1.20.1"
HEXCASTING_VERSION = "0.11.2-pre-702"
INLINE_VERSION = "1.0.2-51"
KOTLIN_LOADER_VERSION = "1.13.7+kotlin.2.2.21"
LOADER_VERSION = "0.18.0"
MAVEN_GROUP = "org.robbie"
MINECRAFT_VERSION = "1.20.1"
MOD_VERSION = "0.3.1"
ORG_GRADLE_JVMARGS = "-Xmx1G"
PATCHOULI_VERSION = "84"
PAUCAL_VERSION = "0.6.0-pre-118"
SPECTRUM_VERSION = "1.8.11"
YARN_MAPPINGS = "1.20.1+build.10"
